@@ -6,8 +6,7 @@ module MultiJson
     class Nsjsonserialization < MultiJson::Adapters::OkJson
       ParseError = ::MultiJson::OkJson::Error
 
-      def self.load(string, options={})
-        string = string.read if string.respond_to?(:read)
+      def load(string, options={})
         data = string.dataUsingEncoding(NSUTF8StringEncoding)
         object = NSJSONSerialization.JSONObjectWithData(data, options: NSJSONReadingMutableContainers | NSJSONReadingMutableLeaves, error: nil)
         if object
@@ -18,7 +17,7 @@ module MultiJson
         end
       end
 
-      def self.dump(object, options={})
+      def dump(object, options={})
         pretty = options[:pretty] ? NSJSONWritingPrettyPrinted : 0
         object = object.as_json if object.respond_to?(:as_json)
         if NSJSONSerialization.isValidJSONObject(object)
