@@ -72,6 +72,11 @@ describe MultiJson do
     expect(MultiJson.adapter).to eq(MultiJson::Adapters::JsonGem)
   end
 
+  it 'is settable via a case-insensitive string' do
+    MultiJson.use 'Json_Gem'
+    expect(MultiJson.adapter).to eq(MultiJson::Adapters::JsonGem)
+  end
+
   it 'is settable via a class' do
     adapter = Class.new
     MultiJson.use adapter
@@ -84,8 +89,15 @@ describe MultiJson do
     expect(MultiJson.adapter).to eq(adapter)
   end
 
-  it 'throws ArgumentError on bad input' do
-    expect{ MultiJson.use 'bad adapter' }.to raise_error(ArgumentError)
+  it 'throws AdapterError on bad input' do
+    expect{ MultiJson.use 'bad adapter' }.to raise_error(MultiJson::AdapterError, /bad adapter/)
+  end
+
+  it 'gives access to original error when raising AdapterError' do
+    exception = get_exception(MultiJson::AdapterError){ MultiJson.use 'foobar' }
+    expect(exception.cause).to be_instance_of(::LoadError)
+    expect(exception.message).to include("-- multi_json/adapters/foobar")
+    expect(exception.message).to include("Did not recognize your adapter specification")
   end
 
   context 'using one-shot parser' do
@@ -169,22 +181,6 @@ describe MultiJson do
 
   it_behaves_like 'has options', MultiJson
 
-  # %w(gson jr_jackson json_gem json_pure nsjsonserialization oj ok_json yajl).each do |adapter|
-  #   next if !jruby? && %w(gson jr_jackson).include?(adapter)
-  #   next if !macruby? && adapter == 'nsjsonserialization'
-  #   next if jruby? && %w(oj yajl).include?(adapter)
-
-  #   context adapter do
-  #     it_behaves_like 'an adapter', adapter
-  #   end
-  # end
-
-  # %w(json_gem json_pure).each do |adapter|
-  #   context adapter do
-  #     it_behaves_like 'JSON-like adapter', adapter
-  #   end
-  # end
-
   describe 'aliases' do
     if jruby?
       describe 'jrjackson' do
