@@ -1,15 +1,3 @@
-require 'simplecov'
-# require 'coveralls'
-
-# SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
-#   SimpleCov::Formatter::HTMLFormatter,
-#   Coveralls::SimpleCov::Formatter
-# ]
-# SimpleCov.start do
-#   add_filter 'spec'
-#   add_filter 'vendor'
-# end
-
 require 'multi_json'
 require 'rspec'
 
@@ -70,4 +58,20 @@ def simulate_no_adapters
       yield
     end
   end
-end
\ No newline at end of file
+end
+
+def get_exception(exception_class = StandardError)
+  begin
+    yield
+  rescue exception_class => exception
+    exception
+  end
+end
+
+def with_default_options
+  adapter = MultiJson.adapter
+  adapter.load_options = adapter.dump_options = MultiJson.load_options = MultiJson.dump_options = nil
+  yield
+ensure
+  adapter.load_options = adapter.dump_options = MultiJson.load_options = MultiJson.dump_options = nil
+end
